# -*- coding: utf-8 -*-

from series_intro_recognizer.tp.interval import Interval
from series_intro_recognizer.processors.audio_samples import recognise_from_audio_samples
from series_intro_recognizer.processors.audio_files import recognise_from_audio_files
